OC.L10N.register(
    "mail",
    {
    "Auto detect failed. Please use manual mode." : "Methodd awtoganfod. Defnyddiwch y modd llaw.",
    "Updating account failed: " : "Methodd diweddaru'r cyfrif :",
    "Creating account failed: " : "Methodd creu'r cyfrif:",
    "Mail" : "E-bost",
    "Auto" : "Awto",
    "Name" : "Enw",
    "Mail Address" : "Cyfeiriad E-bost",
    "Password" : "Cyfrinair",
    "Manual" : "Â Llaw",
    "IMAP Settings" : "Gosodiadau IMAP",
    "IMAP Host" : "Gwesteiwr IMAP",
    "IMAP Security" : "Diogelwch IMAP",
    "None" : "Dim",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Porth IMAP",
    "IMAP User" : "Defnyddiwr IMAP",
    "IMAP Password" : "Cyfrinair IMAP",
    "SMTP Settings" : "Gosodiadau SMTP",
    "SMTP Host" : "Gwesteiwr SMTP",
    "SMTP Security" : "Diogelwch SMTP",
    "SMTP Port" : "Porth SMTP",
    "SMTP User" : "Defnyddiwr SMTP",
    "SMTP Password" : "Cyfrinair SMTP",
    "Save" : "Cadw",
    "Connect" : "Cysylltu",
    "Add mail account" : "Ychwanegu cyfrif post",
    "Use Gravatar and favicon avatars" : "Defnyddiwch Gravatar ac afatarau favicon",
    "Subject" : "Pwnc",
    "Saving draft …" : "Yn cadw drafft …",
    "Draft saved" : "Cadwyd y drafft",
    "Upload attachment" : "Llwytho atodiad",
    "Add attachment from Files" : "Ychwanegwch atodiad o'r Ffeiliau",
    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "Chwilio am ffordd i amgryptio'ch e-byst? Gosodwch estyniad porwr Mailvelope!",
    "Uploading attachments …" : "Llwytho atodiadau ...",
    "Sending …" : "Anfon",
    "Error sending your message" : "Gwall wrth anfon eich neges",
    "Go back" : "Nôl",
    "Retry" : "Ceisio eto",
    "Message sent!" : "Neges wedi'i hanfon!",
    "Write another message" : "Ysgrifennu neges arall",
    "Send" : "Anfon",
    "Uploading {percent}% …" : "Llwytho {percent}% ...",
    "Choose a file to add as attachment" : "Dewiswch ffeil i'w hychwanegu fel atodiad",
    "No messages in this folder" : "Dim negeseuon yn y ffolder hon",
    "Draft: " : "Drafft:",
    "Mark unread" : "Nodi heb ei ddarllen",
    "Mark read" : "Marcio wedi'i ddarllen",
    "Select" : "Select",
    "Delete" : "Dileu",
    "Report this bug" : "Cofnodi'r gwall",
    "Loading messages" : "Llwytho negeseuon",
    "Favorites" : "Ffefrynnau",
    "Other" : "Arall",
    "Import into calendar" : "Mewnforio i'r calendr",
    "Download attachment" : "Llwytho'r atodiad i lawr",
    "Save to Files" : "Cadw i Ffeiliau",
    "Choose a folder to store the attachment in" : "Dewiswch ffolder i gadw'r atodiad ynddi",
    "Save all to Files" : "Cadw'r cyfan i Ffeiliau",
    "Choose a folder to store the attachments in" : "Dewiswch ffolder i gadw'r atodiadau ynddi",
    "The images have been blocked to protect your privacy." : "Mae'r delweddau wedi'u rhwystro i ddiogelu eich preifatrwydd.",
    "New message" : "Neges newydd",
    "Settings" : "Gosodiadau",
    "Add folder" : "Ychwanegu ffolder",
    "Loading …" : "Yn llwytho …",
    "Cancel" : "Diddymu",
    "Show all folders" : "Dangos pob ffolder",
    "Collapse folders" : "Cwympo ffolderi",
    "Mark all as read" : "Marcio'r cyfan wedi'u darllen",
    "Add subfolder" : "Ychwanegu is-ffolder",
    "Not found" : "Heb ei ganfod",
    "Could not load your draft" : "Methu llwytho eich drafft",
    "No message selected" : "Dim neges wedi'i dewis",
    "Signature" : "Llofnod",
    "General" : "Cyffredinol",
    "User" : "User",
    "Mail server" : "Gweinydd e-bost",
    "Keyboard shortcuts" : "Llwybrau byr bysellfwrdd",
    "Speed up your Mail experience with these quick shortcuts." : "Cyflymwch eich profiad E-bost gyda'r llwybrau byr cyflym hyn.",
    "Compose new message" : "Ysgrifennu Neges _Newydd",
    "Newer message" : "Neges diweddarach",
    "Older message" : "Neges hyn",
    "Toggle star" : "Toglo seren",
    "Toggle unread" : "Toglo heb ei darllen",
    "Search" : "Chwilio",
    "Refresh" : "Ail-lwytho",
    "Connect your mail account" : "Cysylltu â'r cyfrif e-bost",
    "All" : "Popeth",
    "Archive" : "Archif",
    "Drafts" : "Drafftiau",
    "All inboxes" : "Pob blwch derbyn",
    "Inbox" : "Blwch Derbyn",
    "Junk" : "Sothach",
    "Sent" : "Anfonwyd",
    "Trash" : "Sbwriel",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["oddi wrth {from}","oddi wrth {from}","oddi wrth {from}","oddi wrth {from}"],
    "Nextcloud Mail" : "E-bost Nextcloud",
    "Could not load {tag}{name}{endtag}" : "Methu llwytho {tag} {name} {endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Bu anhawster wrth lwytho {tag}{name}{endtag}",
    "Could not load your message" : "Methu llwytho'ch neges",
    "Could not load the desired message" : "Methu llwytho'r neges a ddewiswyd",
    "Could not load the message" : "Methu llwytho'r neges",
    "Error loading message" : "Gwall wrth lwytho neges",
    "Forwarding to %s" : "Anfon ymlaen at %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Cliciwch yma os na chewch eich ailgyfeirio'n awtomatig o fewn yr ychydig eiliadau nesaf.",
    "Redirect" : "Ailgyfeirio",
    "The link leads to %s" : "Mae'r ddolen yn arwain at %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Os nad ydych am ymweld â'r dudalen honno, gallwch ddychwelyd i'r <a href=\"%s\">E-bost</a> .",
    "Continue to %s" : "Parhau i %s"
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
